"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.determinePackageManager = exports.showNxWarning = void 0;
const path = require("path");
const child_process_1 = require("child_process");
const output_1 = require("@nrwl/workspace/src/utils/output");
function showNxWarning(workspaceName) {
    try {
        const pathToRunNxCommand = path.resolve(process.cwd(), workspaceName);
        child_process_1.execSync('nx --version', {
            cwd: pathToRunNxCommand,
            stdio: ['ignore', 'ignore', 'ignore'],
        });
    }
    catch (e) {
        // no nx found
        output_1.output.addVerticalSeparator();
        output_1.output.note({
            title: `Nx CLI is not installed globally.`,
            bodyLines: [
                `This means that you might have to use "yarn nx" or "npm nx" to execute commands in the workspace.`,
                `Run "yarn global add nx" or "npm install -g nx" to be able to execute command directly.`,
            ],
        });
    }
}
exports.showNxWarning = showNxWarning;
function determinePackageManager(preferredPackageManager) {
    return ([
        preferredPackageManager,
        getPackageManagerFromAngularCLI(),
        'yarn',
        'pnpm',
    ].find((pm) => pm && isPackageManagerInstalled(pm)) || 'npm');
}
exports.determinePackageManager = determinePackageManager;
function getPackageManagerFromAngularCLI() {
    // If you have Angular CLI installed, read Angular CLI config.
    try {
        return child_process_1.execSync('ng config -g cli.packageManager', {
            stdio: ['ignore', 'pipe', 'ignore'],
            timeout: 500,
        })
            .toString()
            .trim();
    }
    catch (e) {
        return;
    }
}
function isPackageManagerInstalled(packageManager) {
    let isInstalled = false;
    try {
        child_process_1.execSync(`${packageManager} --version`, {
            stdio: ['ignore', 'ignore', 'ignore'],
        });
        isInstalled = true;
    }
    catch (e) {
        /* do nothing */
    }
    return isInstalled;
}
//# sourceMappingURL=shared.js.map